==> alibabacloud-oss-v2-1.0.1.dev2.tar.gz: alibabacloud-oss-v2-1.0.1.dev2/alibabacloud_oss_v2/__init__.py <==
from .types import *

# sub mod
from . import credentials
from . import retry
from . import signer
from . import transport
from . import models
from . import exceptions
from . import crypto
from . import checkpoint

# all types in models
from .models.enums import *
from .models.service import *
from .models.region import *
from .models.bucket_basic import *
from .models.object_basic import *
from .models.access_point import *
from .models.bucket_access_monitor import *
from .models.bucket_archive_direct_read import *
from .models.bucket_cname import *
from .models.bucket_lifecycle import *
from .models.bucket_cors import *
from .models.bucket_policy import *
from .models.bucket_encryption import *
from .models.bucket_logging import *
from .models.bucket_inventory import *
from .models.bucket_website import *
from .models.bucket_replication import *
from .models.bucket_referer import *

from .config import Config
from .client import Client
from .encryption_client import EncryptionClient, EncryptionMultiPartContext

from .downloader import (
    Downloader,
    DownloadResult,
    DownloadError,
)

from .uploader import (
    Uploader,
    UploadResult,
    UploadError
)

from .paginator import (
    ListObjectsPaginator,
    ListObjectsV2Paginator,
    ListObjectVersionsPaginator,
    ListBucketsPaginator,
    ListPartsPaginator,
    ListMultipartUploadsPaginator
)

from .filelike import (
    AppendOnlyFile,
    ReadOnlyFile,
    PathError
)

from .io_utils import (
    StreamBodyDiscarder
)

from ._version import VERSION
__version__ = VERSION

==> alibabacloud-oss-v2-1.2.0.tar.gz: alibabacloud-oss-v2-1.2.0/alibabacloud_oss_v2/__init__.py <==
from .types import *

# sub mod
from . import credentials
from . import retry
from . import signer
from . import transport
from . import models
from . import exceptions
from . import checkpoint

# all types in models
from .models.enums import *
from .models.service import *
from .models.region import *
from .models.bucket_basic import *
from .models.object_basic import *
from .models.access_point import *
from .models.bucket_access_monitor import *
from .models.bucket_archive_direct_read import *
from .models.bucket_cname import *
from .models.bucket_lifecycle import *
from .models.bucket_cors import *
from .models.bucket_policy import *
from .models.bucket_encryption import *
from .models.bucket_logging import *
from .models.bucket_inventory import *
from .models.bucket_website import *
from .models.bucket_replication import *
from .models.bucket_referer import *
from .models.bucket_worm import *
from .models.bucket_request_payment import *
from .models.access_point_public_access_block import *
from .models.bucket_data_redundancy_transition import *
from .models.bucket_transfer_acceleration import *
from .models.bucket_public_access_block import *
from .models.public_access_block import *
from .models.bucket_resource_group import *
from .models.bucket_style import *
from .models.bucket_tags import *
from .models.bucket_meta_query import *
from .models.bucket_https_config import *
from .models.cloud_box import *

from .config import Config
from .client import Client

# If the Crypto(pycryptodome) module was not imported, the encryption feature is not supported.
try:
    from . import crypto
    from .encryption_client import EncryptionClient, EncryptionMultiPartContext
except ImportError:
    pass

from .downloader import (
    Downloader,
    DownloadResult,
    DownloadError,
)

from .uploader import (
    Uploader,
    UploadResult,
    UploadError
)

from .copier import (
    Copier,
    CopyResult,
    CopyError
)

from .paginator import (
    ListObjectsPaginator,
    ListObjectsV2Paginator,
    ListObjectVersionsPaginator,
    ListBucketsPaginator,
    ListPartsPaginator,
    ListMultipartUploadsPaginator
)

from .filelike import (
    AppendOnlyFile,
    ReadOnlyFile,
    PathError
)

from .io_utils import (
    StreamBodyDiscarder
)

from ._version import VERSION
__version__ = VERSION
